using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.EcommerceProvider;

public partial class Custom_CustomCheckoutProcess : CMSAbstractWebPart
{

    private int orderId = 0;
    private static string SESSION_KEY = "CustomCheckoutProcess";


    /// <summary>
    /// Custom checkout process definition.
    /// </summary>
    public string CustomCheckoutProcess
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("CustomCheckoutProcess"), "");
        }
        set
        {
            this.SetValue("CustomCheckoutProcess", value);
            InitializeProcess(value);
        }
    }


    /// <summary>
    /// Shopping cart which stores all data during the checkout process.
    /// </summary>
    private ShoppingCartInfo ShoppingCartInfoObj
    {
        get
        {
            return (ShoppingCartInfo)Session[SESSION_KEY];
        }
        set
        {
            Session[SESSION_KEY] = value;
        }
    }


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if (!this.StopProcessing)
        {
            InitializeProcess(this.CustomCheckoutProcess);
        }
    }


    /// <summary>
    /// Initializes checkout process
    /// </summary>
    /// <param name="processDefinition">Checkout process XML definition</param>
    protected void InitializeProcess(string processDefinition)
    {
        // Load shopping cart object from saved order
        if ((!IsPostBack) || (this.ShoppingCartInfoObj == null))
        {
            orderId = ValidationHelper.GetInteger(Request.QueryString["orderid"], 0);
            if (orderId > 0)
            {
                this.ShoppingCartInfoObj = ShoppingCartInfoProvider.GetShoppingCartInfoFromOrder(orderId);                
            }
        }

        // Initialize checkout process
        cartElem.CheckoutProcessType = CheckoutProcessEnum.Custom;
        cartElem.LoadCheckoutProcess(new CheckoutProcessInfo(processDefinition));
        cartElem.LocalShoppingCart = this.ShoppingCartInfoObj;
    }
}
