using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.EcommerceProvider;
using CMS.GlobalHelper;

public partial class TestingPages_OrderPayment : ShoppingCartStep
{    
    protected void Page_Load(object sender, EventArgs e)
    {     
        // Override button settings
        this.ShoppingCartControl.ButtonBack.Visible = false;
        this.ShoppingCartControl.ButtonNext.Text = "Finish payment";

        // Initialize standard authorize.net form
        this.AuthorizeNetForm1.ShoppingCartControl = this.ShoppingCartControl;

        LoadData();
    }

    private void LoadData()
    {
        if (this.ShoppingCartInfoObj != null)
        {            
            OrderInfo oi = OrderInfoProvider.GetOrderInfo(this.ShoppingCartInfoObj.OrderId);
            if (oi != null)
            {
                // Show formatted total price
                lblTotalPrice.Text =  CurrencyInfoProvider.GetFormatedPrice(oi.OrderTotalPrice, this.ShoppingCartInfoObj.CurrencyInfoObj);

                // Show formatted amount from the total price which was already paid 
                double paid = ValidationHelper.GetDouble(oi.GetValue("OrderPaidAmount"), 0);
                lblPaid.Text = CurrencyInfoProvider.GetFormatedPrice(paid, this.ShoppingCartInfoObj.CurrencyInfoObj);                

                // Show formatted amount from the total price which should be paid
                double notPaid = oi.OrderTotalPrice - paid;
                lblNotPaid.Text = CurrencyInfoProvider.GetFormatedPrice(notPaid, this.ShoppingCartInfoObj.CurrencyInfoObj);
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = "Payment cannot be processed - Order data not found.";
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = "Payment cannot be processed - Order data not found.";
        }
    }

    public override bool IsValid()
    {        
        // Validate custom data
        if (txtPay.Text.Trim() == "")
        {
            lblError.Visible = true;
            lblError.Text = "Please enter some price.";
            return false;

            // You will need to add another validations to prevent from sending to 
            // Authorize.Net more money than the OrderNotPaied etc.
        }

        // Validate credit card information
        return (this.AuthorizeNetForm1.ValidateData() == "");        
    }


    public override bool ProcessStep()
    {
        string errorMessage = "";
        string infoMessage = "";

        // Ensure authorize.net payment method with following code name is registered and enabled
        string paymentCodeName = "CustomAuthorizeNet";

        // Get authorize.net payment method
        PaymentOptionInfo payment = PaymentOptionInfoProvider.GetPaymentOptionInfo(paymentCodeName, this.ShoppingCartInfoObj.SiteName);

        if ((payment != null) && (payment.PaymentOptionEnabled))
        {
            // Save selected payment method
            this.ShoppingCartInfoObj.ShoppingCartPaymentOptionID = payment.PaymentOptionID;

            // Save entered price
            this.ShoppingCartInfoObj.PaymentGatewayCustomData["price"] = txtPay.Text.Trim();

            // Save credit card information
            errorMessage = this.AuthorizeNetForm1.ProcessData();
           
            if ((errorMessage == "") && (this.ShoppingCartControl.PaymentGatewayProvider != null))
            {
                // Proces payment
                this.ShoppingCartControl.PaymentGatewayProvider.ProcessPayment();
                
                // Update order paid amount
                if (this.ShoppingCartControl.PaymentGatewayProvider.IsPaymentCompleted)
                {
                    OrderInfo oi = OrderInfoProvider.GetOrderInfo(this.ShoppingCartInfoObj.OrderId);
                    if (oi != null)
                    {
                        // Get previously paid amount
                        double paidAmount = ValidationHelper.GetDouble(oi.GetValue("OrderPaidAmount"), 0);

                        // Get actual amount which was sent to the payment gateway
                        double actualAmount = ValidationHelper.GetDouble(this.ShoppingCartInfoObj.PaymentGatewayCustomData["price"], 0);

                        // Update total paid amount
                        oi.SetValue("OrderPaidAmount", paidAmount + actualAmount);

                        try
                        {
                            OrderInfoProvider.SetOrderInfo(oi);
                        }
                        catch (Exception ex)
                        {                            
                            errorMessage = "Unable to update order paid amount: " + ex.Message;
                        }
                    }
                    else
                    {
                        errorMessage = "Unable to update order paid amount - Order was not found.";
                    }
                }

                // Get error and info messages from payment provider
                errorMessage += this.ShoppingCartControl.PaymentGatewayProvider.ErrorMessage;
                infoMessage = this.ShoppingCartControl.PaymentGatewayProvider.InfoMessage;
             
            }
            else
            {                
                errorMessage = "Payment processing failed - payment provider not found.";                
            } 
        }
        else
        {            
            errorMessage = "Payment processing failed - payment method not enabled.";            
        }

        if (infoMessage != "")
        {
            // Show info message
            lblInfo.Visible = true;
            lblInfo.Text = infoMessage;
        }
        
        if (errorMessage != "")
        {
            // Show error message
            lblError.Visible = true;
            lblError.Text = errorMessage;
            return false;
        }
        else
        {
            // OK
            return true;
        }        
    }
}
